@@ -1,6 +1,6 @@
 /* glibconfig.h
  *
- * This is a generated file.  Please modify 'configure.ac'
+ * This is a generated file.  Please modify 'glibconfig.h.in'
  */
 
 #ifndef __GLIBCONFIG_H__
@@ -18,6 +18,9 @@
  */
 #define GLIB_USING_SYSTEM_PRINTF
 
+/* #undef GLIB_STATIC_COMPILATION */
+/* #undef GOBJECT_STATIC_COMPILATION */
+
 G_BEGIN_DECLS
 
 #define G_MINFLOAT	FLT_MIN
@@ -36,16 +39,23 @@ G_BEGIN_DECLS
 
 typedef signed char gint8;
 typedef unsigned char guint8;
+
 typedef signed short gint16;
 typedef unsigned short guint16;
+
 #define G_GINT16_MODIFIER "h"
 #define G_GINT16_FORMAT "hi"
 #define G_GUINT16_FORMAT "hu"
+
+
 typedef signed int gint32;
 typedef unsigned int guint32;
+
 #define G_GINT32_MODIFIER ""
 #define G_GINT32_FORMAT "i"
 #define G_GUINT32_FORMAT "u"
+
+
 #define G_HAVE_GINT64 1          /* deprecated, always true */
 
 G_GNUC_EXTENSION typedef signed long long gint64;
@@ -53,10 +63,12 @@ G_GNUC_EXTENSION typedef unsigned long long guint64;
 
 #define G_GINT64_CONSTANT(val)	(G_GNUC_EXTENSION (val##LL))
 #define G_GUINT64_CONSTANT(val)	(G_GNUC_EXTENSION (val##ULL))
+
 #define G_GINT64_MODIFIER "ll"
 #define G_GINT64_FORMAT "lli"
 #define G_GUINT64_FORMAT "llu"
 
+
 #define GLIB_SIZEOF_VOID_P 4
 #define GLIB_SIZEOF_LONG   4
 #define GLIB_SIZEOF_SIZE_T 4
@@ -83,7 +95,6 @@ typedef gint64 goffset;
 
 #define G_POLLFD_FORMAT "%d"
 
-
 #define GPOINTER_TO_INT(p)	((gint)  (gint) (p))
 #define GPOINTER_TO_UINT(p)	((guint) (guint) (p))
 
@@ -96,23 +107,25 @@ typedef unsigned int guintptr;
 #define G_GINTPTR_MODIFIER      ""
 #define G_GINTPTR_FORMAT        "i"
 #define G_GUINTPTR_FORMAT       "u"
+
 #ifndef G_DISABLE_DEPRECATED
 #define g_ATEXIT(proc)	(atexit (proc))
 #define g_memmove(dest,src,len) G_STMT_START { memmove ((dest), (src), (len)); } G_STMT_END
 #endif
 
 #define GLIB_MAJOR_VERSION 2
-#define GLIB_MINOR_VERSION 56
-#define GLIB_MICRO_VERSION 2
+#define GLIB_MINOR_VERSION 58
+#define GLIB_MICRO_VERSION 1
 
 #define G_OS_UNIX
 
+#define G_VA_COPY va_copy
 
-#define G_VA_COPY	va_copy
 
 #ifndef __cplusplus
 # define G_HAVE_ISO_VARARGS 1
 #endif
+
 #ifdef __cplusplus
 # define G_HAVE_ISO_VARARGS 1
 #endif
@@ -125,10 +138,13 @@ typedef unsigned int guintptr;
 #  undef G_HAVE_ISO_VARARGS
 #endif
 
-#define G_HAVE_GNUC_VARARGS 1
-#define G_HAVE_GROWING_STACK 0
-
+#undef G_HAVE_GROWING_STACK
 #define G_HAVE_GNUC_VISIBILITY 1
+
+#ifndef _MSC_VER
+# define G_HAVE_GNUC_VARARGS 1
+#endif
+
 #if defined(__SUNPRO_C) && (__SUNPRO_C >= 0x590)
 #define G_GNUC_INTERNAL __attribute__((visibility("hidden")))
 #elif defined(__SUNPRO_C) && (__SUNPRO_C >= 0x550)
@@ -142,20 +158,24 @@ typedef unsigned int guintptr;
 #define G_THREADS_ENABLED
 #define G_THREADS_IMPL_POSIX
 
-#define G_ATOMIC_LOCK_FREE
+#undef G_ATOMIC_OP_MEMORY_BARRIER_NEEDED
+/* #undef G_ATOMIC_LOCK_FREE */
 
 #define GINT16_TO_LE(val)	((gint16) (val))
 #define GUINT16_TO_LE(val)	((guint16) (val))
 #define GINT16_TO_BE(val)	((gint16) GUINT16_SWAP_LE_BE (val))
 #define GUINT16_TO_BE(val)	(GUINT16_SWAP_LE_BE (val))
+
 #define GINT32_TO_LE(val)	((gint32) (val))
 #define GUINT32_TO_LE(val)	((guint32) (val))
 #define GINT32_TO_BE(val)	((gint32) GUINT32_SWAP_LE_BE (val))
 #define GUINT32_TO_BE(val)	(GUINT32_SWAP_LE_BE (val))
+
 #define GINT64_TO_LE(val)	((gint64) (val))
 #define GUINT64_TO_LE(val)	((guint64) (val))
 #define GINT64_TO_BE(val)	((gint64) GUINT64_SWAP_LE_BE (val))
 #define GUINT64_TO_BE(val)	(GUINT64_SWAP_LE_BE (val))
+
 #define GLONG_TO_LE(val)	((glong) GINT32_TO_LE (val))
 #define GULONG_TO_LE(val)	((gulong) GUINT32_TO_LE (val))
 #define GLONG_TO_BE(val)	((glong) GINT32_TO_BE (val))
